@@ -254,6 +254,24 @@ class EnvAble(Able):
 
 
 def cheat(set_to: Any, typed: Type, value: Any, nested: bool = True, self: bool = True, nested_count: int = 1):
+    def _set_conf_able(obj, conf) -> bool:
+        for base in obj.__orig_bases__:
+            if "ConfAble" in base.__name__:
+                conf_class = get_args(base)[0]
+                for attr in vars(conf).values():
+                    if isinstance(attr, conf_class):
+                        obj.conf = attr
+                        loguru.logger.success(
+                            f"[CONF_ABLE::{obj.__class__.__name__}] Set {attr.__class__.__name__}")
+                        return True
+                    elif issubclass(attr.__class__, BaseModel):
+                        if _set_conf_able(obj, attr):
+                            return True
+            if base == Generic[GenConfig]:
+                obj.conf = value
+                return True
+        return False
+
     def set_up(target: GenAble):
         if typed == EnvAble:
             target.env = value
@@ -268,17 +286,7 @@ def cheat(set_to: Any, typed: Type, value: Any, nested: bool = True, self: bool
             target.shared_state = value
             return True
         if typed == ConfAble:
-            for base in target.__orig_bases__:
-                if "ConfAble" in base.__name__:
-                    conf_class = get_args(base)[0]
-                    for attr in vars(value).values():
-                        if isinstance(attr, conf_class):
-                            target.conf = attr
-                            return True
-                if base == Generic[GenConfig]:
-                    target.conf = value
-                    return True
-            return False
+            return _set_conf_able(target, value)
         return False
 
     def proc(_item):
@@ -288,14 +296,13 @@ def cheat(set_to: Any, typed: Type, value: Any, nested: bool = True, self: bool
                     f"[CYCLE::{nested_count}][OBJECT::{set_to.__class__.__name__}] "
                     f"- Set({typed.__name__},{name}:{item.__class__.__name__})")
             is_set = set_up(_item)
-
             if settings.DEBUG:
                 if is_set:
                     loguru.logger.success(
                         f"[CYCLE::{nested_count}][OBJECT::{_item.__class__.__name__}] Set {typed.__name__}")
                 else:
                     loguru.logger.error(
-                        f"[CYCLE::{nested_count}][OBJECT::{_item.__class__.__name__}] NOT SET {typed.__name__} ")
+                        f"[CYCLE::{nested_count}][OBJECT::{_item.__class__.__name__}] NOT SET {typed.__name__}")
             if nested:
                 cheat(_item, typed, value,
                       nested_count=nested_count + 1)
@@ -639,6 +646,7 @@ class ITransport(ConfAble[TransportConf], ChanAble, EnvAble, SharedStateAble, me
         for service in self.services:
             service.transport = self
         self.rt_writers = {}
+        self._plugins_store = None
         self.plugins_dir = None
 
     def get_service(self, typed: Type[GenService]) -> GenService | None:
@@ -687,6 +695,8 @@ class ITransport(ConfAble[TransportConf], ChanAble, EnvAble, SharedStateAble, me
 
     @property
     def plugins(self):
+        if not self._plugins_store:
+            return []
         return [container.plugin for container in self._plugins_store.local_store.values()]
 
 
